.. _api_reference:

=============
API reference
=============


System
======

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: System
   :template: autosummary/module_toctree.rst

   ams.system


Model
======

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: Model
   :template: autosummary/module_toctree.rst

   ams.core.model
   ams.core.param
   ams.core.service


Routines
========

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: Routines
   :template: autosummary/module_toctree.rst

   ams.routines.routine
   ams.routines.dcopf
   ams.routines.pflow


Optimization
=============

.. autosummary::
   :maxdepth:4
   :recursive:
   :toctree: _generated
   :caption: Optimization
   :template: autosummary/module_toctree.rst

   ams.opt


I/O
===

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: I/O
   :template: autosummary/module_toctree.rst

   ams.io


Interoperability
================

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: Interoperability
   :template: autosummary/module_toctree.rst

   ams.interface


Others
======

.. autosummary::
   :maxdepth:4
   :toctree: _generated
   :recursive:
   :caption: Others
   :template: autosummary/module_toctree.rst

   ams.cli
   ams.main
   ams.utils.paths
